[Bf-blender-cvs] SVN commit: /data/svn/bf-blender [48556] trunk/blender: First load of spell and typo fixes (mostly UI messages, but also one or two pieces of code using mis-spelled names).

Bastien Montagne montagne29 at wanadoo.fr
Tue Jul 3 19:20:21 CEST 2012


Revision: 48556
          http://projects.blender.org/scm/viewvc.php?view=rev&root=bf-blender&revision=48556
Author:   mont29
Date:     2012-07-03 17:20:21 +0000 (Tue, 03 Jul 2012)
Log Message:
-----------
First load of spell and typo fixes (mostly UI messages, but also one or two pieces of code using mis-spelled names).

Modified Paths:
--------------
    trunk/blender/release/scripts/modules/bpy_extras/io_utils.py
    trunk/blender/release/scripts/startup/bl_ui/properties_data_armature.py
    trunk/blender/release/scripts/startup/bl_ui/properties_physics_field.py
    trunk/blender/source/blender/blenkernel/intern/particle_system.c
    trunk/blender/source/blender/editors/armature/armature_intern.h
    trunk/blender/source/blender/editors/armature/armature_ops.c
    trunk/blender/source/blender/editors/armature/poselib.c
    trunk/blender/source/blender/editors/curve/editcurve.c
    trunk/blender/source/blender/editors/interface/interface_templates.c
    trunk/blender/source/blender/editors/io/io_collada.c
    trunk/blender/source/blender/editors/mask/mask_shapekey.c
    trunk/blender/source/blender/editors/space_view3d/view3d_buttons.c
    trunk/blender/source/blender/makesdna/DNA_object_force.h
    trunk/blender/source/blender/makesrna/intern/rna_constraint.c
    trunk/blender/source/blender/makesrna/intern/rna_modifier.c
    trunk/blender/source/blender/makesrna/intern/rna_object.c
    trunk/blender/source/blender/makesrna/intern/rna_object_force.c
    trunk/blender/source/blender/makesrna/intern/rna_smoke.c
    trunk/blender/source/blender/makesrna/intern/rna_tracking.c
    trunk/blender/source/blender/makesrna/intern/rna_userdef.c

Modified: trunk/blender/release/scripts/modules/bpy_extras/io_utils.py
===================================================================
--- trunk/blender/release/scripts/modules/bpy_extras/io_utils.py	2012-07-03 16:59:27 UTC (rev 48555)
+++ trunk/blender/release/scripts/modules/bpy_extras/io_utils.py	2012-07-03 17:20:21 UTC (rev 48556)
@@ -330,7 +330,7 @@
         description="Method used to reference paths",
         items=(('AUTO', "Auto", "Use Relative paths with subdirectories only"),
                ('ABSOLUTE', "Absolute", "Always write absolute paths"),
-               ('RELATIVE', "Relative", "Always write relative patsh "
+               ('RELATIVE', "Relative", "Always write relative paths "
                                         "(where possible)"),
                ('MATCH', "Match", "Match Absolute/Relative "
                                   "setting with input path"),

Modified: trunk/blender/release/scripts/startup/bl_ui/properties_data_armature.py
===================================================================
--- trunk/blender/release/scripts/startup/bl_ui/properties_data_armature.py	2012-07-03 16:59:27 UTC (rev 48555)
+++ trunk/blender/release/scripts/startup/bl_ui/properties_data_armature.py	2012-07-03 17:20:21 UTC (rev 48556)
@@ -203,7 +203,7 @@
                 col.operator("poselib.pose_remove", icon='ZOOMOUT', text="")
                 col.operator("poselib.apply_pose", icon='ZOOM_SELECTED', text="").pose_index = poselib.pose_markers.active_index
 
-            col.operator("poselib.action_sanitise", icon='HELP', text="")  # XXX: put in menu?
+            col.operator("poselib.action_sanitize", icon='HELP', text="")  # XXX: put in menu?
 
             # properties for active marker
             if pose_marker_active is not None:

Modified: trunk/blender/release/scripts/startup/bl_ui/properties_physics_field.py
===================================================================
--- trunk/blender/release/scripts/startup/bl_ui/properties_physics_field.py	2012-07-03 16:59:27 UTC (rev 48555)
+++ trunk/blender/release/scripts/startup/bl_ui/properties_physics_field.py	2012-07-03 17:20:21 UTC (rev 48556)
@@ -195,7 +195,7 @@
             col = split.column()
             col.label(text="Particle:")
             col.prop(settings, "permeability", slider=True)
-            col.prop(settings, "stickness")
+            col.prop(settings, "stickiness")
             col.prop(settings, "use_particle_kill")
             col.label(text="Particle Damping:")
             sub = col.column(align=True)

Modified: trunk/blender/source/blender/blenkernel/intern/particle_system.c
===================================================================
--- trunk/blender/source/blender/editors/armature/armature_intern.h	2012-07-03 16:59:27 UTC (rev 48555)
+++ trunk/blender/source/blender/editors/armature/armature_intern.h	2012-07-03 17:20:21 UTC (rev 48556)
@@ -183,7 +183,7 @@
 void POSELIB_OT_new(struct wmOperatorType *ot);
 void POSELIB_OT_unlink(struct wmOperatorType *ot);
 
-void POSELIB_OT_action_sanitise(struct wmOperatorType *ot);
+void POSELIB_OT_action_sanitize(struct wmOperatorType *ot);
 
 void POSELIB_OT_pose_add(struct wmOperatorType *ot);
 void POSELIB_OT_pose_remove(struct wmOperatorType *ot);

Modified: trunk/blender/source/blender/editors/armature/armature_ops.c
===================================================================
--- trunk/blender/source/blender/editors/armature/armature_ops.c	2012-07-03 16:59:27 UTC (rev 48555)
+++ trunk/blender/source/blender/editors/armature/armature_ops.c	2012-07-03 17:20:21 UTC (rev 48556)
@@ -159,7 +159,7 @@
 	WM_operatortype_append(POSELIB_OT_new);
 	WM_operatortype_append(POSELIB_OT_unlink);
 	
-	WM_operatortype_append(POSELIB_OT_action_sanitise);
+	WM_operatortype_append(POSELIB_OT_action_sanitize);
 	
 	/* POSE SLIDING */
 	WM_operatortype_append(POSE_OT_push);

Modified: trunk/blender/source/blender/editors/armature/poselib.c
===================================================================
--- trunk/blender/source/blender/editors/armature/poselib.c	2012-07-03 16:59:27 UTC (rev 48555)
+++ trunk/blender/source/blender/editors/armature/poselib.c	2012-07-03 17:20:21 UTC (rev 48556)
@@ -288,7 +288,7 @@
 /* This tool automagically generates/validates poselib data so that it corresponds to the data 
  * in the action. This is for use in making existing actions usable as poselibs.
  */
-static int poselib_sanitise_exec(bContext *C, wmOperator *op)
+static int poselib_sanitize_exec(bContext *C, wmOperator *op)
 {
 	Object *ob = get_poselib_object(C);
 	bAction *act = (ob) ? ob->poselib : NULL;
@@ -353,15 +353,15 @@
 	return OPERATOR_FINISHED;
 }
 
-void POSELIB_OT_action_sanitise(wmOperatorType *ot)
+void POSELIB_OT_action_sanitize(wmOperatorType *ot)
 {
 	/* identifiers */
-	ot->name = "Sanitise Pose Library Action";
-	ot->idname = "POSELIB_OT_action_sanitise";
+	ot->name = "Sanitize Pose Library Action";
+	ot->idname = "POSELIB_OT_action_sanitize";
 	ot->description = "Make action suitable for use as a Pose Library";
 	
 	/* callbacks */
-	ot->exec = poselib_sanitise_exec;
+	ot->exec = poselib_sanitize_exec;
 	ot->poll = has_poselib_pose_data_poll;
 	
 	/* flags */

Modified: trunk/blender/source/blender/editors/curve/editcurve.c
===================================================================
--- trunk/blender/source/blender/editors/curve/editcurve.c	2012-07-03 16:59:27 UTC (rev 48555)
+++ trunk/blender/source/blender/editors/curve/editcurve.c	2012-07-03 17:20:21 UTC (rev 48556)
@@ -2368,7 +2368,7 @@
 {
 	/* identifiers */
 	ot->name = "Smooth Curve Radius";
-	ot->description = "Flatten radiuses of selected points";
+	ot->description = "Flatten radii of selected points";
 	ot->idname = "CURVE_OT_smooth_radius";
 	
 	/* api clastbacks */

Modified: trunk/blender/source/blender/editors/interface/interface_templates.c
===================================================================
--- trunk/blender/source/blender/editors/interface/interface_templates.c	2012-07-03 16:59:27 UTC (rev 48555)
+++ trunk/blender/source/blender/editors/interface/interface_templates.c	2012-07-03 17:20:21 UTC (rev 48556)
@@ -782,7 +782,7 @@
 			if (modifier_couldBeCage(scene, md) && (index <= lastCageIndex)) {
 				/* -- convert to rna ? */
 				but = uiDefIconButBitI(block, TOG, eModifierMode_OnCage, 0, ICON_MESH_DATA, 0, 0, UI_UNIT_X - 2, UI_UNIT_Y, &md->mode, 0.0, 0.0, 0.0, 0.0,
-				                       TIP_("Apply modifier to editing cage during Editmode"));
+				                       TIP_("Apply modifier to editing cage during Edit mode"));
 				if (index < cageIndex)
 					uiButSetFlag(but, UI_BUT_DISABLED);
 				uiButSetFunc(but, modifiers_setOnCage, ob, md);
@@ -2699,7 +2699,8 @@
 	uiBlockSetEmboss(block, UI_EMBOSSN);
 
 	if (reports->list.first != reports->list.last)
-		uiDefIconButO(block, BUT, "UI_OT_reports_to_textblock", WM_OP_INVOKE_REGION_WIN, icon, 2, 0, UI_UNIT_X, UI_UNIT_Y, TIP_("Click to see rest of reports in textblock: 'Recent Reports'"));
+		uiDefIconButO(block, BUT, "UI_OT_reports_to_textblock", WM_OP_INVOKE_REGION_WIN, icon, 2, 0,
+		              UI_UNIT_X, UI_UNIT_Y, TIP_("Click to see the remaining reports in text block: 'Recent Reports'"));
 	else
 		uiDefIconBut(block, LABEL, 0, icon, 2, 0, UI_UNIT_X, UI_UNIT_Y, NULL, 0.0f, 0.0f, 0, 0, "");
 

Modified: trunk/blender/source/blender/editors/io/io_collada.c
===================================================================
--- trunk/blender/source/blender/editors/io/io_collada.c	2012-07-03 16:59:27 UTC (rev 48555)
+++ trunk/blender/source/blender/editors/io/io_collada.c	2012-07-03 17:20:21 UTC (rev 48556)
@@ -276,7 +276,7 @@
 	RNA_def_boolean(ot->srna, "include_material_textures", 0, "Include Material Textures",
 					"Export textures assigned to the object Materials");
 
-	RNA_def_boolean(ot->srna, "use_texture_copies", 1, "copy", 
+	RNA_def_boolean(ot->srna, "use_texture_copies", 1, "Copy", 
 	                "Copy textures to same folder where the .dae file is exported");
 
 

Modified: trunk/blender/source/blender/editors/mask/mask_shapekey.c
===================================================================
--- trunk/blender/source/blender/editors/mask/mask_shapekey.c	2012-07-03 16:59:27 UTC (rev 48555)
+++ trunk/blender/source/blender/editors/mask/mask_shapekey.c	2012-07-03 17:20:21 UTC (rev 48556)
@@ -229,7 +229,7 @@
 {
 	/* identifiers */
 	ot->name = "Feather Reset Animation";
-	ot->description = "Resets fearther weights on all selected points animation values";
+	ot->description = "Reset feather weights on all selected points animation values";
 	ot->idname = "MASK_OT_shape_key_feather_reset";
 
 	/* api callbacks */
@@ -394,7 +394,7 @@
 {
 	/* identifiers */
 	ot->name = "Re-Key Points of Selected Shapes";
-	ot->description = "Recalculates animation data on selected points for frames selected in the dopesheet";
+	ot->description = "Recalculate animation data on selected points for frames selected in the dopesheet";
 	ot->idname = "MASK_OT_shape_key_rekey";
 
 	/* api callbacks */

Modified: trunk/blender/source/blender/editors/space_view3d/view3d_buttons.c
===================================================================

@@ Diff output truncated at 10240 characters. @@



More information about the Bf-blender-cvs mailing list
--- trunk/blender/source/blender/blenkernel/intern/particle_system.c	2012-07-03 16:59:27 UTC (rev 48555)
+++ trunk/blender/source/blender/blenkernel/intern/particle_system.c	2012-07-03 17:20:21 UTC (rev 48556)
@@ -3320,10 +3320,10 @@
 			}
 		}
 
 		/* stickness was possibly added before, so cancel that before calculating new normal velocity */
 		/* otherwise particles go flying out of the surface because of high reversed sticky velocity */
 		if (v0_dot < 0.0f) {
-			v0_dot += pd->pdef_stickness;
+			v0_dot += pd->pdef_stickiness;
 			if (v0_dot > 0.0f)
 				v0_dot = 0.0f;
 		}
@@ -3379,8 +3379,8 @@
 				madd_v3_v3fl(pa->state.vel, nor, -dot);
 		}
 
-		/* add stickness to surface */
-		madd_v3_v3fl(pa->state.vel, pce->nor, -pd->pdef_stickness);
+		/* add stickiness to surface */
+		madd_v3_v3fl(pa->state.vel, pce->nor, -pd->pdef_stickiness);
 
 		/* set coordinates for next iteration */
 		copy_v3_v3(col->co1, co);
@@ -3320,10 +3320,10 @@
 		}
 
-		/* stickness was possibly added before, so cancel that before calculating new normal velocity */
+		/* stickiness was possibly added before, so cancel that before calculating new normal velocity */
 		/* otherwise particles go flying out of the surface because of high reversed sticky velocity */
 		if (v0_dot < 0.0f) {

Modified: trunk/blender/source/blender/editors/armature/armature_intern.h
===================================================================